/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.context;

import dk.sds.nsp.security.SecurityContext;
import dk.sundhedsdatastyrelsen.livstestamente.util.RoleMappingProperties;

import java.util.Map;
import java.util.Optional;

public class UserTitleProvider {
    private final String SUNDHEDSFAGLIG_UKENDT_USER_TITLE;
    private final String BORGER_USER_TITLE;
    private final Map<String, String > mappingRoles;

    public UserTitleProvider(RoleMappingProperties roleMappingProperties) {
        this.SUNDHEDSFAGLIG_UKENDT_USER_TITLE = roleMappingProperties.getUnknownUser();
        this.BORGER_USER_TITLE = roleMappingProperties.getBorgerUser();
        this.mappingRoles = roleMappingProperties.getAllMappingValues();
    }

    public String getSundhedsfagligUserTitle(SecurityContext.User user) {
        // Hvis der er en uddannelse kode, brug den, ellers brug national rolle, hvis ingen af dem er tilstede, brug "unverified role"
        return Optional.ofNullable(user)
                .map((u) -> u.getCredentials().isPresent() ? u.getCredentials().get() : null)
                .map(this::mapCredentialsToTitle)
                .orElse(SUNDHEDSFAGLIG_UKENDT_USER_TITLE);
    }

    private String mapCredentialsToTitle(SecurityContext.User.Credentials credentials){
        if (credentials.getEducationCode().isPresent()) {
            return mapUserTitle(credentials.getEducationCode().get());
        } else if (credentials.getNationalRole().isPresent()) {
            return mapUserTitle(credentials.getNationalRole().get());
        }
        return null;
    }

    private String mapUserTitle(String userTitle) {
        if (userTitle != null && !userTitle.isEmpty()) {
            String convertedTitle =  mappingRoles.get(userTitle);
            if (convertedTitle != null ) {
                return convertedTitle;
            }
        }
        return userTitle;
    }

    public String getBorgerUserTitle() {
        return BORGER_USER_TITLE;
    }
}
