/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.livstestamente.util;

import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.ExpectedException;

import java.util.Map;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

public class RoleMappingPropertiesTest {

    @Rule
    public ExpectedException exceptionRule = ExpectedException.none();

    @Test
    public void testAllLineRead() {

        // given

        // when
        RoleMappingProperties roleMappingProperties = new RoleMappingProperties();

        // then
        assertNotNull(roleMappingProperties.getAllMappingValues());
        assertEquals(32, roleMappingProperties.getAllMappingValues().size());

        for (Map.Entry<String, String> entry : roleMappingProperties.getAllMappingValues().entrySet()) {
            assertNotNull(entry.getKey());
            assertNotNull(entry.getValue());
        }

    }

    @Test
    public void testSpecificValues() {

        // given

        // when
        RoleMappingProperties roleMappingProperties = new RoleMappingProperties();

        // then
        assertEquals("borger", roleMappingProperties.getBorgerUser());
        assertEquals("unverified role", roleMappingProperties.getUnknownUser());

    }

    @Test
    public void testErrorDuringLoad() {

        // given
        exceptionRule.expect(RuntimeException.class);
        exceptionRule.expectMessage("Error reading role mapping configuration from one of the properties citizen.user, healthcareprofessional.unknown.user from: /nsp-role-mapping_invalid.properties");

        // when
        RoleMappingProperties roleMappingProperties = new RoleMappingProperties("/nsp-role-mapping_invalid.properties");

        // then
        //exception

    }

}
